//-----------------------------------------------------------------------------
// File name:       OSMutex.cpp
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Included Files
//-----------------------------------------------------------------------------
#include "OS/OSDefines.h"
#include "OS/OSMutex.h"

#include <stdint.h>
#include <stdbool.h>
#include "pthread.h"

//-----------------------------------------------------------------------------
// Public Static Functions
//-----------------------------------------------------------------------------
bool COSMutex::CreateMutex(OSMutex* createdMutex)
{
    bool mutexCreated = false;
    int32_t result;

    result = pthread_mutex_init(createdMutex, NULL);
    if (result == OS_SUCCESS)
    {
        mutexCreated = true;
    }

    return mutexCreated;
}

//-----------------------------------------------------------------------------

void COSMutex::DestroyMutex(OSMutex* mutex)
{
    pthread_mutex_destroy(mutex);
}

//-----------------------------------------------------------------------------

bool COSMutex::LockMutex(OSMutex* mutex)
{
    bool locked = false;
    int32_t result;

    result = pthread_mutex_lock(mutex);
    if (result == OS_SUCCESS)
    {
        locked = true;
    }

    return locked;
}

//-----------------------------------------------------------------------------

bool COSMutex::UnlockMutex(OSMutex* mutex)
{
    bool unlocked = false;
    int32_t result;

    result = pthread_mutex_unlock(mutex);
    if (result == OS_SUCCESS)
    {
        unlocked = true;
    }

    return unlocked;
}

//-----------------------------------------------------------------------------

bool COSMutex::TryLockMutex(OSMutex* mutex)
{
    bool locked = false;
    int32_t result;

    result = pthread_mutex_trylock(mutex);
    if (result == OS_SUCCESS)
    {
        locked = true;
    }

    return locked;
}
