//-----------------------------------------------------------------------------
// File name:       OSTask.h
//-----------------------------------------------------------------------------

#ifndef _OS_TASK_H_
#define _OS_TASK_H_

//-----------------------------------------------------------------------------
// Included Files
//-----------------------------------------------------------------------------
#include <stdint.h>
#include <stdbool.h>

#include "pthread.h"

//-----------------------------------------------------------------------------
// Class Definition
//-----------------------------------------------------------------------------
class COSTask
{
public:
    // Constants
    static const uint32_t DEFAULT_MINIMUM_TASK_STACK_SIZE = 2048;

    // Definitions
    typedef void* (* OSTaskFunction)(void *);
    typedef pthread_t OSTaskHandle;

    // Constructor/Destructor
    COSTask(void) = default;
    ~COSTask(void) = default;

    // Static Functions
    static bool CreateTask(OSTaskFunction taskFunctionPointer,
                           uint32_t taskStackSize,
                           void* taskParameters,
                           uint8_t taskPriority,
                           OSTaskHandle* createdTaskHandle);
    static void DestroyTask(OSTaskHandle taskHandle);

    static void TaskSleep(uint32_t sleepTimeInMilliseconds);
    static void TaskYield(void);
    static uint32_t GetMinimumTaskStackSize(void);
    static uint32_t GetMinimumDefaultTaskStackSize(void);
    static uint32_t ValidateTaskStackSize(uint32_t requestedSize);
};

#endif // _OS_TASK_H_
